# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/libs/09_btyp.ipynb.

# %% auto 0
__all__ = ['Adata', 'Adatas', 'AnnData', 'AnnDatas']

# %% ../nbs/libs/09_btyp.ipynb 4
from typing import TypeAlias, List

# %% ../nbs/libs/09_btyp.ipynb 6
try:
    import anndata as ad
    adata  = ad.AnnData
    adatas = List[adata]
except ImportError:
    # Define a placeholder type if anndata is not installed
    adata = 'anndata.AnnData'
    adatas = List[adata]

# %% ../nbs/libs/09_btyp.ipynb 7
Adata: TypeAlias = adata
Adatas: TypeAlias = adatas

AnnData: TypeAlias = adata
AnnDatas: TypeAlias = adatas
