# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/atyp',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/atyp',
                'lib_path': 'atyp'},
  'syms': { 'atyp.atyp': {},
            'atyp.btyp': {},
            'atyp.ctyp': {},
            'atyp.dtyp': {},
            'atyp.mtyp': {},
            'atyp.ptyp': {},
            'atyp.qtyp': {},
            'atyp.rtyp': {},
            'atyp.ztyp': {}}}
