# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/libs/06_rtyp.ipynb.

# %% auto 0
__all__ = ['RTree', 'RText', 'RCons', 'RProg', 'TApp']

# %% ../nbs/libs/06_rtyp.ipynb 4
from typing import TypeAlias

# %% ../nbs/libs/06_rtyp.ipynb 6
try:
    from rich.tree import Tree
    from rich.text import Text
    from rich.console import Console
    from rich.progress import Progress
    tree = Tree
    text = Text
    cons = Console
    prog = Progress
    
except ImportError:
    tree = 'rich.tree.Tree'
    text = 'rich.text.Text'
    cons = 'rich.console.Console'
    prog = 'rich.progress.Progress'

# %% ../nbs/libs/06_rtyp.ipynb 7
RTree: TypeAlias = tree
RText: TypeAlias = text
RCons: TypeAlias = cons
RProg: TypeAlias = prog

# %% ../nbs/libs/06_rtyp.ipynb 9
try:
    from typer import Typer
    tapp = Typer    
except ImportError:
    tapp = 'typer.Typer'

# %% ../nbs/libs/06_rtyp.ipynb 10
TApp: TypeAlias = tapp
