# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/01_ctyp.ipynb.

# %% auto 0
__all__ = ['ClsInt', 'ClsSet', 'ClsStr', 'ClsObj', 'ClsBool', 'ClsBoolish', 'ClsCall', 'ClsType', 'ClsList', 'ClsFloat',
           'ClsNumber', 'ClsComplex']

# %% ../nbs/01_ctyp.ipynb 4
from typing import (
    Type, TypeAlias, ClassVar, Callable
)

# %% ../nbs/01_ctyp.ipynb 5
from .atyp import Boolish, Numeric, StrLike

# %% ../nbs/01_ctyp.ipynb 7
ClsInt = ClassVar[int]
ClsSet = ClassVar[set]
ClsStr = ClassVar[str]
ClsObj = ClassVar[object]

ClsBool = ClassVar[bool]
ClsBoolish = ClassVar[Boolish]
ClsCall = ClassVar[Callable]

ClsType = ClassVar[type]
ClsList = ClassVar[list]

ClsFloat = ClassVar[float]
ClsNumber = ClassVar[Numeric]
ClsComplex = ClassVar[complex]
