# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/libs/10_mtyp.ipynb.

# %% auto 0
__all__ = ['Tensor', 'Device']

# %% ../nbs/libs/10_mtyp.ipynb 4
from typing import TypeAlias

# %% ../nbs/libs/10_mtyp.ipynb 6
try:
    import torch
    tensor = torch.Tensor
    device = torch.device
except ImportError:
    # Define a placeholder type if torch is not installed
    tensor = 'torch.Tensor'
    device = 'torch.device'

# %% ../nbs/libs/10_mtyp.ipynb 7
Tensor: TypeAlias = tensor
Device: TypeAlias = device
