# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/libs/07_ptyp.ipynb.

# %% auto 0
__all__ = ['Axes', 'ColorMap', 'CBarPos']

# %% ../nbs/libs/07_ptyp.ipynb 4
from typing import TypeAlias, Tuple

# %% ../nbs/libs/07_ptyp.ipynb 6
try:
    import matplotlib as mpl
    from matplotlib.axes._axes import Axes

    cmap = mpl.colors.Colormap
    axes = Axes

except ImportError:
    cmap = 'matplotlib.colors.Colormap'
    axes = 'matplotlib.axes._axes.Axes'

# %% ../nbs/libs/07_ptyp.ipynb 7
Axes: TypeAlias = axes
ColorMap: TypeAlias = cmap

# CBarPos: tuple of (left, bottom, width, height)
CBarPos: TypeAlias = Tuple[float, float, float, float]
