# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/03_ztyp.ipynb.

# %% auto 0
__all__ = ['FlagFunc', 'FlagFuncQ']

# %% ../nbs/03_ztyp.ipynb 4
from typing import List, Union, TypeAlias, Callable, Optional, ParamSpec

# %% ../nbs/03_ztyp.ipynb 6
from .atyp import Boolish
from .qtyp import AnyQ

# %% ../nbs/03_ztyp.ipynb 7
FlagFunc: TypeAlias = Callable[[AnyQ], Boolish]

FlagFuncQ: TypeAlias = Optional[FlagFunc]
